Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1054)

Unified Diff: content/renderer/media/audio_input_message_filter.h

Issue 324143002: Decouple IPC::MessageFilter from IPC::Channel (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Landing Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/input/input_event_filter.cc ('k') | content/renderer/media/audio_input_message_filter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/audio_input_message_filter.h
diff --git a/content/renderer/media/audio_input_message_filter.h b/content/renderer/media/audio_input_message_filter.h
index 82b4dd02a4198b1843ea1241d1a74473b05e7eec..1107463eb96674bd0a83218255ee4ff14512e141 100644
--- a/content/renderer/media/audio_input_message_filter.h
+++ b/content/renderer/media/audio_input_message_filter.h
@@ -54,7 +54,7 @@ class CONTENT_EXPORT AudioInputMessageFilter : public IPC::MessageFilter {
// IPC::MessageFilter override. Called on |io_message_loop_|.
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
- virtual void OnFilterAdded(IPC::Channel* channel) OVERRIDE;
+ virtual void OnFilterAdded(IPC::Sender* sender) OVERRIDE;
virtual void OnFilterRemoved() OVERRIDE;
virtual void OnChannelClosing() OVERRIDE;
@@ -80,8 +80,8 @@ class CONTENT_EXPORT AudioInputMessageFilter : public IPC::MessageFilter {
// A map of stream ids to delegates.
IDMap<media::AudioInputIPCDelegate> delegates_;
- // IPC channel for Send(), must only be accesed on |io_message_loop_|.
- IPC::Channel* channel_;
+ // IPC sender for Send(), must only be accesed on |io_message_loop_|.
+ IPC::Sender* sender_;
// Message loop on which IPC calls are driven.
const scoped_refptr<base::MessageLoopProxy> io_message_loop_;
« no previous file with comments | « content/renderer/input/input_event_filter.cc ('k') | content/renderer/media/audio_input_message_filter.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698